@@ -6,7 +6,7 @@
 
 print("this is my init file")
 
-import API_Call
+from .API_Call import API
 import  atr
 
 
